@@ -17,13 +17,14 @@ class ZanshinRunner : public Plasma::AbstractRunner
     Q_OBJECT
 
 public:
-    ZanshinRunner(QObject *parent, const QVariantList &args);
+    ZanshinRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args);
     ~ZanshinRunner();
 
     void match(Plasma::RunnerContext &context) override;
     void run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &action) override;
 private:
     Domain::TaskRepository::Ptr m_taskRepository;
+    const QString m_triggerWord;
 };
 
 
